function A = SLbendPsi( lengthPhi, diffPhi, scale, nScales, ...
                        rows, cols, shear, bend, alpha)
   
   curvaturemult = lengthPhi*diffPhi/4;

   %make wavelet depending on scale:
   [~,psi,~] = wavefun('db8',nScales-scale+1);
   
   % make shorter lowpass filter:
   subx1 = 2^(scale*alpha);
   phi = ones(1,floor(lengthPhi/subx1));
   for u = 1:diffPhi
   phi = conv(phi,  ones(1,floor(lengthPhi/subx1)));
   end
   
   high = phi.'*psi;
   
   [a1,a2] = size(high);
   high = padarray(high, floor([(rows-a1)/2 (cols-a2)/2]), 0, 'pre');
   high = padarray(high, ceil([(rows-a1)/2 (cols-a2)/2]), 0, 'post');
   
         
   % apply shearing and bending
   for k = 1:rows
        high(k,:) = circshift(high(k,:).', floor(shear*(k-cols/2) + bend/curvaturemult*(k-cols/2)^2)).';
   end
   
   % normalize
   high = high/norm(high(:));

   % show elements
   if(false)
   imagesc(real(high));
   pause(0.1);
   end
   
   A = high;
   
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  Copyright (c) 2016, Philipp Petersen and Christian Lessig.
%
%  If you use or mention this code in a publication please cite 
%  C. Lessig, P. Petersen, M. Schfer, Bendlets: A Second Order Shearlet
%    Transform with Bent Elements.
% 
%  This file is part of BendLab: A Bendlet Toolbox.
% 
%  BendLab is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
% 
%  BendLab is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License for more details.
% 
%  You should have received a copy of the GNU General Public License
%  along with BendLab.  If not, see <http://www.gnu.org/licenses/>.
