function X = BLbendrec2DSparse( coeffs, bendletSystem)
%
% BLbendrec2DSparse: Bendlet reconstruction of 2D data using sparse
%                    representation.
%
% Input:
%
%         coeffs: cell array of sparse bendlet coefficients of size N x M.
%  bendletSystem: Bendlet system whose size matches coeffs, i.e. N x M with
%                 k elements.
%
% Output:
%
%      X: sparse N x M array containing signal represented by coeffs. 
%
% Example:
%
% X = double(imread('Data/Snowman.png'));
% bendletSystemSparse =  BLgetBendletSystem2DSparse( size(X,1), size(X,2));
% coeffs = BLbenddec2DSparse( X, bendletSystemSparse);
% Xtilde = BLbendrec2DSparse( coeffs, bendletSystemSparse);

    if nargin < 2
        error('Not enough input parameters!');
    end
    
    Xfreq = zeros(size(coeffs{1},1),size(coeffs{1},2));
   
    for j = 1:bendletSystem.nBendlets
        psihat = fftshift( fft2( full( bendletSystem.bendlets{j})));
        coeffshat = fft2( fftshift( full( coeffs{j})));
        Xfreq = Xfreq + (coeffshat .* psihat);
    end
    
    X = ifft2(ifftshift((1./bendletSystem.dualFrameWeights) .* Xfreq));

end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  Copyright (c) 2016, Philipp Petersen and Christian Lessig.
%
%  If you use or mention this code in a publication please cite 
%  C. Lessig, P. Petersen, M. Schfer, Bendlets: A Second Order Shearlet
%    Transform with Bent Elements.
% 
%  This file is part of BendLab: A Bendlet Toolbox.
% 
%  BendLab is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
% 
%  BendLab is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License for more details.
% 
%  You should have received a copy of the GNU General Public License
%  along with BendLab.  If not, see <http://www.gnu.org/licenses/>.
